summaryrefslogtreecommitdiffstats
path: root/tdecore/kapplication.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-08 17:42:48 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-08 17:42:48 -0600
commite81c741bb2cf337a43524e75f22f7728ce17a343 (patch)
tree7fcea2ffd9c3420af999c3dcad0ed032eef93956 /tdecore/kapplication.cpp
parent9c30c9c89ce69ed1b76ff47ca092c6bee7c8e43b (diff)
downloadtdelibs-e81c741bb2cf337a43524e75f22f7728ce17a343.tar.gz
tdelibs-e81c741bb2cf337a43524e75f22f7728ce17a343.zip
Rename additional KDE strings
Diffstat (limited to 'tdecore/kapplication.cpp')
-rw-r--r--tdecore/kapplication.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/tdecore/kapplication.cpp b/tdecore/kapplication.cpp
index 5338cfccd..878b6e12f 100644
--- a/tdecore/kapplication.cpp
+++ b/tdecore/kapplication.cpp
@@ -1332,8 +1332,8 @@ static void checkRestartVersion( TQSessionManager& sm )
0, 1, False, AnyPropertyType, &type, &format, &nitems, &after, &data ) == Success ) {
if( data != NULL )
XFree( data );
- if( type == XA_STRING && format == 8 ) { // session set, check if KDE_SESSION_VERSION is not set (meaning KDE3)
- if( XGetWindowProperty( dpy, RootWindow( dpy, 0 ), XInternAtom( dpy, "KDE_SESSION_VERSION", False ),
+ if( type == XA_STRING && format == 8 ) { // session set, check if TDE_SESSION_VERSION is not set (meaning KDE3)
+ if( XGetWindowProperty( dpy, RootWindow( dpy, 0 ), XInternAtom( dpy, "TDE_SESSION_VERSION", False ),
0, 1, False, AnyPropertyType, &type, &format, &nitems, &after, &data ) == Success ) {
if( data != NULL )
XFree( data ); // KDE4 or newer
@@ -1385,7 +1385,7 @@ void KApplication::saveState( TQSessionManager& sm )
// tell the session manager about our new lifecycle
TQStringList restartCommand = sm.restartCommand();
- TQCString multiHead = getenv("KDE_MULTIHEAD");
+ TQCString multiHead = getenv("TDE_MULTIHEAD");
if (multiHead.lower() == "true") {
// if multihead is enabled, we save our -display argument so that
// we are restored onto the correct head... one problem with this